#
# spec file for package ghc-mono-traversable
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name mono-traversable
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.0.11.0
Release:        lp151.1.2
Summary:        Type classes for mapping, folding, and traversing monomorphic containers
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-algorithms-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-foldl-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-semigroups-devel
%endif

%description
Type classes for mapping, folding, and traversing monomorphic containers.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Sun Feb  3 2019 psimons@suse.com
- Update mono-traversable to version 1.0.11.0.
  [#]# 1.0.11.0
  * Adding monomorphic instances for GHC.Generics and Data.Proxy types
    [#175](https://github.com/snoyberg/mono-traversable/issues/175)
* Fri Dec 21 2018 psimons@suse.com
- Update mono-traversable to version 1.0.10.0.
  [#]# 1.0.10.0
  * Make index work on negative indices
    [#172](https://github.com/snoyberg/mono-traversable/issues/172)
    [#114](https://github.com/snoyberg/mono-traversable/issues/114)
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Thu Aug  2 2018 psimons@suse.com
- Update mono-traversable to version 1.0.9.0.
  [#]# 1.0.9.0
  * Added `filterMap` to `Data.Containers`
    [#167](https://github.com/snoyberg/mono-traversable/pull/167)
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update mono-traversable to version 1.0.8.1.
  * Compat with gauge 0.1 and 0.2
  * Switch to gauge
  * Relax constraint on `singleton` to `MonoPointed`
    [#156](https://github.com/snoyberg/mono-traversable/issues/156)
  * Add `dropPrefix` and `dropSuffix` to `Data.Sequences` [#139](https://github.com/snoyberg/mono-traversable/issues/139)
  * Change `sort` implementation [#153](https://github.com/snoyberg/mono-traversable/issues/153)
  * Add `mapNonNull` function to `Data.NonNull` [#150](https://github.com/snoyberg/mono-traversable/issues/150)
  * Move `oelem` and `onotElem` into the `MonoFoldable` class [#133](https://github.com/snoyberg/mono-traversable/issues/133)
  * Change `instance MonoFoldable (Set e)` to `instance Ord e => MonoFoldable (Set e)`
  * Add `dropEnd` function to the `IsSequence` class, and a specialized implementation for `Text`
  * Add `ensurePrefix` and `ensureSuffix` functions [#141](https://github.com/snoyberg/mono-traversable/pull/141)
  * Fix test suite for foldl 1.3
* Tue Mar  7 2017 psimons@suse.com
- Update to version 1.0.2 with cabal2obs.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 1.0.1.3 with cabal2obs.
* Mon Feb 20 2017 psimons@suse.com
- Update to version 1.0.1.2 with cabal2obs.
* Thu Jan 26 2017 psimons@suse.com
- Update to version 1.0.1.1 with cabal2obs.
* Mon Jan 16 2017 psimons@suse.com
- Update to version 1.0.1 revision 1 with cabal2obs.
* Mon Sep 26 2016 psimons@suse.com
- Update to version 1.0.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 1.0.0.1 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.10.2 revision 0 with cabal2obs.
* Wed Apr 13 2016 mimi.vx@gmail.com
- update to 0.10.2
  * Add delete and deleteBy methods to EqSequence
* Tue Feb 16 2016 mimi.vx@gmail.com
- update to 0.10.1.1
  * Remove unneeded INLINEs
* Tue Jan 26 2016 mimi.vx@gmail.com
- update to 0.10.1
  * Allow comonad-5
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 0.10.0.1
  * Remove Functor instance for MinLen
  * Instance for Data.Sequence.Seq is incorrect.
* Tue Nov 17 2015 mimi.vx@gmail.com
- initial commit
